@@ -31,6 +31,7 @@ except:
 import gdb
 import os
 import os.path
+import re
 import sys
 import struct
 import tempfile
@@ -353,8 +354,8 @@ class Dumper(DumperBase):
                 gdb.TYPE_CODE_STRING : TypeCodeFortranString,
             }[code]
             if tdata.code == TypeCodeEnum:
-                tdata.enumDisplay = lambda intval, addr : \
-                    self.nativeTypeEnumDisplay(nativeType, intval)
+                tdata.enumDisplay = lambda intval, addr, form : \
+                    self.nativeTypeEnumDisplay(nativeType, intval, form)
             if tdata.code == TypeCodeStruct:
                 tdata.lalignment = lambda : \
                     self.nativeStructAlignment(nativeType)
@@ -385,13 +386,13 @@ class Dumper(DumperBase):
         targs2 = self.listTemplateParametersManually(str(nativeType))
         return targs if len(targs) >= len(targs2) else targs2
 
-    def nativeTypeEnumDisplay(self, nativeType, intval):
+    def nativeTypeEnumDisplay(self, nativeType, intval, form):
         try:
             enumerators = []
             for field in nativeType.fields():
                 # If we found an exact match, return it immediately
                 if field.enumval == intval:
-                    return '%s (%d)' % (field.name, intval)
+                    return field.name + ' (' + (form % intval) + ')'
                 enumerators.append((field.name, field.enumval))
 
             # No match was found, try to return as flags
@@ -407,13 +408,13 @@ class Dumper(DumperBase):
             if not found or v != 0:
                 # Leftover value
                 flags.append('unknown:%d' % v)
-            return "(%s) (%d)" % (" | ".join(flags), intval)
+            return " | ".join(flags) + ' (' + (form % intval) + ')'
         except:
             pass
-        return '%d' % intval
+        return form % intval
 
     def nativeTypeId(self, nativeType):
-        if nativeType.code == gdb.TYPE_CODE_TYPEDEF:
+        if nativeType and (nativeType.code == gdb.TYPE_CODE_TYPEDEF):
             return '%s{%s}' % (nativeType, nativeType.strip_typedefs())
         name = str(nativeType)
         if len(name) == 0:
@@ -461,9 +462,10 @@ class Dumper(DumperBase):
         val = self.fromNativeValue(nativeMember)
         nativeFieldType = nativeField.type.unqualified()
         if nativeField.bitsize:
-            val.lvalue = str(int(nativeMember))
+            val.lvalue = int(nativeMember)
             val.laddress = None
-            val.type = self.createBitfieldType(str(nativeFieldType), nativeField.bitsize)
+            fieldType = self.fromNativeType(nativeFieldType)
+            val.type = self.createBitfieldType(fieldType, nativeField.bitsize)
         val.isBaseClass = nativeField.is_base_class
         val.name = fieldName
         return val
@@ -488,10 +490,6 @@ class Dumper(DumperBase):
 
         #warn('LISTING FIELDS FOR %s' % nativeType)
         for nativeField in nativeType.fields():
-            #if nativeField.bitpos is None:
-            #    # This could be a static data member. Ignore it
-            #    #warn('   STATIC MEMBER: %s' % nativeMember)
-            #    continue
             fieldName = nativeField.name
             # Something without a name.
             # Anonymous union? We need a dummy name to distinguish
@@ -505,7 +503,12 @@ class Dumper(DumperBase):
                 anonNumber += 1
                 fieldName = '#%s' % anonNumber
             #warn('FIELD: %s' % fieldName)
-            yield self.fromNativeField(nativeField, nativeValue, fieldName)
+            # hasattr(nativeField, 'bitpos') == False indicates a static field,
+            # but if we have access to a nativeValue .fromNativeField will
+            # also succeed. We essentially skip only static members from
+            # artificial values, like array members constructed from address.
+            if hasattr(nativeField, 'bitpos') or nativeValue is not None:
+                yield self.fromNativeField(nativeField, nativeValue, fieldName)
 
     def fromNativeField(self, nativeField, nativeValue, fieldName):
         nativeFieldType = nativeField.type.unqualified()
@@ -515,17 +518,18 @@ class Dumper(DumperBase):
         if hasattr(nativeField, 'bitpos'):
             bitpos = nativeField.bitpos
         else:
-            bitpos = None
+            bitpos = 0
 
         if hasattr(nativeField, 'bitsize') and nativeField.bitsize != 0:
             bitsize = nativeField.bitsize
         else:
             bitsize = 8 * nativeFieldType.sizeof
 
+        fieldType = self.fromNativeType(nativeFieldType)
         if bitsize != nativeFieldType.sizeof * 8:
-            fieldType = self.createBitfieldType(str(nativeFieldType), bitsize)
+            fieldType = self.createBitfieldType(fieldType, bitsize)
         else:
-            fieldType = self.fromNativeType(nativeFieldType)
+            fieldType = fieldType
 
         if nativeValue is None:
             extractor = None
@@ -691,7 +695,7 @@ class Dumper(DumperBase):
         self.typesToReport = {}
 
         if self.forceQtNamespace:
-            self.qtNamepaceToReport = self.qtNamespace()
+            self.qtNamespaceToReport = self.qtNamespace()
 
         if self.qtNamespaceToReport:
             self.output += ',qtnamespace="%s"' % self.qtNamespaceToReport
@@ -699,7 +703,7 @@ class Dumper(DumperBase):
 
         self.output += ',partial="%d"' % isPartial
         self.output += ',counts=%s' % self.counts
-        self.output += ',timimgs=%s' % self.timings
+        self.output += ',timings=%s' % self.timings
         self.reportResult(self.output)
 
     def parseAndEvaluate(self, exp):
@@ -730,7 +734,7 @@ class Dumper(DumperBase):
             typeName = "'" + typeName + "'"
         # 'class' is needed, see http://sourceware.org/bugzilla/show_bug.cgi?id=11912
         #exp = '((class %s*)%s)->%s(%s)' % (typeName, value.laddress, function, arg)
-        addr = value.laddress
+        addr = value.address()
         if addr is None:
            addr = self.pokeValue(value)
         #warn('PTR: %s -> %s(%s)' % (value, function, addr))
@@ -739,7 +743,7 @@ class Dumper(DumperBase):
         result = gdb.parse_and_eval(exp)
         #warn('  -> %s' % result)
         res = self.fromNativeValue(result)
-        if value.laddress is None:
+        if value.address() is None:
             self.releaseValue(addr)
         return res
 
@@ -984,10 +988,11 @@ class Dumper(DumperBase):
     def handleNewObjectFile(self, objfile):
         name = objfile.filename
         if self.isWindowsTarget():
-            isQtCoreObjFile = name.find('Qt5Cored.dll') >= 0 or name.find('Qt5Core.dll') >= 0
+            qtCoreMatch = re.match('.*Qt5?Core[^/.]*d?\.dll', name)
         else:
-            isQtCoreObjFile = name.find('/libQt5Core') >= 0
-        if isQtCoreObjFile:
+            qtCoreMatch = re.match('.*/libQt5?Core[^/.]*\.so', name)
+
+        if qtCoreMatch is not None:
             self.handleQtCoreLoaded(objfile)
 
     def handleQtCoreLoaded(self, objfile):
@@ -997,7 +1002,12 @@ class Dumper(DumperBase):
         try:
             symbols = gdb.execute(cmd, to_string = True)
         except:
-            pass
+            # command syntax depends on gdb version - below is gdb 8+
+            cmd = 'maint print msymbols -objfile "%s" -- %s' % (objfile.filename, tmppath)
+            try:
+                symbols = gdb.execute(cmd, to_string = True)
+            except:
+                pass
         ns = ''
         with open(tmppath) as f:
             for line in f:
@@ -1008,6 +1018,13 @@ class Dumper(DumperBase):
                     if len(ns):
                         ns += '::'
                     break
+                if line.find('currentThreadData ') >= 0:
+                    # [ 0] b 0x7ffff67d3000 _ZN2UUL17currentThreadDataE
+                    # section .tbss  UU::currentThreadData qthread_unix.cpp\\n
+                    ns = re.split('_ZN?(\d*)(\w*)L17currentThreadDataE? ', line)[2]
+                    if len(ns):
+                        ns += '::'
+                    break
         os.remove(tmppath)
 
         lenns = len(ns)
@@ -1045,12 +1062,17 @@ class Dumper(DumperBase):
             typeName = typeName[0:pos]
         if typeName in self.qqEditable and not simpleType:
             #self.qqEditable[typeName](self, expr, value)
-            expr = gdb.parse_and_eval(expr)
+            expr = self.parseAndEvaluate(expr)
             self.qqEditable[typeName](self, expr, value)
         else:
             cmd = 'set variable (%s)=%s' % (expr, value)
             gdb.execute(cmd)
 
+    def appendSolibSearchPath(self, args):
+        new = list(map(self.hexdecode, args['path']))
+        old = [gdb.parameter('solib-search-path')]
+        gdb.execute('set solib-search-path %s' % args['separator'].join(old + new))
+
     def watchPoint(self, args):
         self.reportToken(args)
         ns = self.qtNamespace()
@@ -1313,7 +1335,7 @@ class Dumper(DumperBase):
 
             frame = frame.older()
             i += 1
-        self.reportResult('stack={frames=[' + self.output + '].report}')
+        self.reportResult('stack={frames=[' + self.output + ']}')
 
     def createResolvePendingBreakpointsHookBreakpoint(self, args):
         class Resolver(gdb.Breakpoint):
